pub struct HeapScanner;Expand description
HeapScanner reads heap memory for active allocations during snapshot analysis.
All memory reads are validated through ValidRegions to prevent segfaults.
This module only operates during offline analysis and has zero runtime overhead.
Implementations
Sourceimpl HeapScanner
impl HeapScanner
Sourcepub fn scan(allocations: &[ActiveAllocation]) -> Vec<ScanResult>
pub fn scan(allocations: &[ActiveAllocation]) -> Vec<ScanResult>
Scan a list of active allocations, reading their memory content.
Only scans HeapOwner allocations and performs deduplication to avoid redundant scanning of duplicate heap regions.
Returns a ScanResult for each unique heap region. Allocations whose
pointers fall outside valid regions will have memory: None.
Arguments
allocations- List of active allocations to scan.
Example
ⓘ
let results = HeapScanner::scan(&allocations);
for result in results {
if let Some(ref memory) = result.memory {
let view = MemoryView::new(memory);
// ... pass to UTI Engine
}
}Auto Trait Implementations
impl Freeze for HeapScanner
impl RefUnwindSafe for HeapScanner
impl Send for HeapScanner
impl Sync for HeapScanner
impl Unpin for HeapScanner
impl UnsafeUnpin for HeapScanner
impl UnwindSafe for HeapScanner