Module node_id

Module node_id 

Node ID Module

This module provides a unified node identity system for the memscope graph model.

Design Principles

  • Graph identity is independent of memory address
  • NodeID is globally unique and thread-safe
  • Container types do not require a pointer

Architecture

Allocation → NodeID (unique)
Memory Address → Optional pointer
Graph → NodeID-based edges

Structs

NodeId
Unique node identifier

Constants

VIRTUAL_PTR_BASE
Virtual pointer base address for Container types.

Functions

is_virtual_pointer
Check if a pointer is a virtual pointer used for Container types.