pub struct RelationGraph {
pub edges: Vec<RelationEdge>,
}Expand description
A relation graph connecting allocations.
Fields
edges: Vec<RelationEdge>All edges in the graph.
Implementations
Sourceimpl RelationGraph
impl RelationGraph
Sourcepub fn from_view(view: &MemoryView) -> Self
pub fn from_view(view: &MemoryView) -> Self
Build relation graph from MemoryView.
Creates a relation graph from the allocations in a MemoryView. This is a convenience method for the unified analyzer API.
Sourcepub fn add_edge(&mut self, from: usize, to: usize, relation: Relation)
pub fn add_edge(&mut self, from: usize, to: usize, relation: Relation)
Add a single edge to the graph.
Does not add duplicate edges (same from/to/relation).
Sourcepub fn add_edges(&mut self, edges: Vec<RelationEdge>)
pub fn add_edges(&mut self, edges: Vec<RelationEdge>)
Add multiple edges at once.
Sourcepub fn get_inbound_edges(&self, node: usize) -> Vec<&RelationEdge>
pub fn get_inbound_edges(&self, node: usize) -> Vec<&RelationEdge>
Get all inbound edges to a given node.
Sourcepub fn get_outbound_edges(&self, node: usize) -> Vec<&RelationEdge>
pub fn get_outbound_edges(&self, node: usize) -> Vec<&RelationEdge>
Get all outbound edges from a given node.
Sourcepub fn edge_count(&self) -> usize
pub fn edge_count(&self) -> usize
Get the number of edges in the graph.