Module analyzer

Module analyzer 

Analyzer Module - Unified analysis entry point Analyzer Module - Unified analysis entry point.

This module provides the Analyzer which serves as the single entry point for all memory analysis operations. It integrates all analysis modules through a structured interface.

Re-exports

pub use crate::analysis::relation_inference::Relation;

Structs

AnalysisReport
Full analysis report.
Analyzer
Unified analysis entry point.
ClassificationAnalysis
Classification analysis module.
ClassificationSummary
Classification summary.
CycleInfo
Information about a reference cycle.
CycleReport
Cycle detection report.
DetectionAnalysis
Detection analysis module.
ExportEngine
Export engine.
GraphAnalysis
Graph analysis module.
LeakInfo
Information about a leaked allocation.
LeakReport
Memory leak report.
MetricsAnalysis
Metrics analysis module.
MetricsReport
Metrics report.
OwnershipStats
Ownership statistics.
RelationshipEdge
Relationship edge information for visualization.
RelationshipStats
Relationship statistics computed from actual graph analysis.
SafetyAnalysis
Safety analysis module.
SafetySummary
Safety summary.
TimelineAnalysis
Timeline analysis module.
TypeClassification
Classification for a specific type.

Enums

TypeCategory
Type category.