Module metadata

Module metadata 

Metadata Engine - Centralized metadata management Metadata Engine - Centralized metadata management

This module provides the MetadataEngine which is responsible for managing all metadata including variables, scopes, threads, types, and pointers across the memscope system.

Re-exports

pub use engine::MetadataEngine;

Modules

engine
Metadata Engine - Centralized metadata management
registry
Variable Registry - Variable metadata management
scope
Scope Tracker - Scope metadata management
smart_pointers
Smart pointer tracking and analysis
stack_trace
Enhanced stack trace capture and analysis
thread
Thread Registry - Thread metadata management