Module engine

Module engine 

Metadata Engine - Centralized metadata management

This module provides the MetadataEngine which is responsible for managing all metadata including variables, scopes, threads, types, and pointers across the memscope system.

Structs

MetadataEngine
Metadata Engine - Centralized metadata management