pub struct QueryPresets;Expand description
Preset query factory
Implementations
Sourceimpl QueryPresets
impl QueryPresets
Sourcepub fn top_allocations_by_size(limit: usize) -> Query
pub fn top_allocations_by_size(limit: usize) -> Query
Create a query to find top allocations by size
Sourcepub fn top_allocations_by_count(limit: usize) -> Query
pub fn top_allocations_by_count(limit: usize) -> Query
Create a query to find top allocations by count
Sourcepub fn memory_leaks(min_age_ms: u64) -> Query
pub fn memory_leaks(min_age_ms: u64) -> Query
Create a query to find memory leaks
Sourcepub fn large_allocations(min_size: usize) -> Query
pub fn large_allocations(min_size: usize) -> Query
Create a query to find large allocations
Sourcepub fn thread_memory_stats(thread_id: u64) -> Query
pub fn thread_memory_stats(thread_id: u64) -> Query
Create a query to get thread memory statistics
Sourcepub fn scope_memory_stats(scope_name: String) -> Query
pub fn scope_memory_stats(scope_name: String) -> Query
Create a query to get scope memory statistics
Sourcepub fn type_memory_stats(type_name: String) -> Query
pub fn type_memory_stats(type_name: String) -> Query
Create a query to get type memory statistics
Sourcepub fn system_summary() -> Query
pub fn system_summary() -> Query
Create a query to get system-wide summary