pub struct EventSummary {
pub total_event_count: usize,
pub exported_event_count: usize,
pub is_sampled: bool,
pub sampling_strategy: String,
pub total_allocations: usize,
pub active_allocations: usize,
}Expand description
Summary of event data included in the dashboard JSON.
Fields
total_event_count: usizeTotal number of raw events in the event store
exported_event_count: usizeNumber of events included in the dashboard payload
is_sampled: boolWhether a subset of events was exported
sampling_strategy: StringDescription of the sampling strategy
total_allocations: usizeTotal number of allocations (from event reconstruction)
active_allocations: usizeNumber of active allocations
Implementations