Task Registry - Unified task tracking and relationship management Task Registry for unified task tracking
This module provides a centralized registry for task metadata, enabling task relationship tracking and memory attribution.
Structs
- Task
Edge - Task graph edge (parent-child relationship)
- Task
Graph - Task graph
- Task
Guard - Task guard for RAII-style task lifecycle management
- Task
IdRegistry - Task registry for managing task metadata
- Task
Meta - Task metadata
- Task
Node - Task graph node
- Task
Registry Stats - Task registry statistics
Enums
- Task
Status - Task status
Functions
- generate_
task_ id - Generate a new unique task ID with collision detection
- global_
registry - Get the global task registry instance