Capture Engine - Event capture backend
This module provides the CaptureEngine which is responsible for capturing memory events from the application and forwarding them to the EventStore. The CaptureEngine does not store events itself; it only captures and forwards them.
Re-exports
pub use backends::CaptureBackend;pub use backends::CaptureBackendType;pub use engine::CaptureEngine;pub use inference::Confidence;pub use inference::DataSource;pub use inference::InferenceEngine;pub use inference::InferenceRule;pub use inference::InferredBorrowInfo;pub use inference::InferredSmartPointerInfo;pub use inference::SmartPointerType as InferredSmartPointerType;pub use types::AllocationInfo;pub use types::BorrowInfo;pub use types::CloneInfo;pub use types::MemoryStats;pub use types::SmartPointerInfo;pub use types::SmartPointerType;pub use types::TrackingError;pub use types::TrackingResult;